function animate_res(Q,fc,tau,ind_tau,ind_j,segLen,output,i)
% input: 
% Q = matrix of generalized coordinates or states (one frame correponds to one column)
% fc = contact forces: [grf;grm]
% tau = joint torques
% ind_tau = indices of torques to display
% ind_j = corresponding joint indices
% segLen = segment lengths of subject
% output = path to file
% i = figure to use

fig = figure(i);clf;

% scale factors for size of spheres and arrows
f_scale = 1/40;
m_scale = 1/3;
tau_scale = 1/20;

show_control = true;

% get joint positions from generalized coord.
ntau = length(ind_tau);
n = size(fc,2);
tvec = 1:n;
sub = subject_blade_legs(segLen); % subject dimensions and inertia
kin = generateModel_blade_legs(sub); % kinematic chain
Nj = kin.N_J; % number of joints

Xj = zeros(3*Nj,n);
cop = zeros(6,n);
tau_ctr = zeros(3*ntau,n);
for i = 1:n
    kin = updateKin_blade_legs_mex(Q(1:kin.DOF,i),zeros(kin.DOF,1),kin,uint8(2));
    Xj(:,i) = kin.Xj(1:3*Nj);
    for j = 1:ntau
        tau_ctr([j,ntau+j,2*ntau+j],i) = Xj([ind_j(j),Nj+ind_j(j),2*Nj+ind_j(j)],i);
    end
    cop(:,i) = kin.Xs([3*4+1:3*5,3*7+1:3*8]);
end

% index order for plotting
indOrder = [2,1,3,4,5,6,5,4,3,1,7,8,9,10];

% plot initial frame
h = plot3(Xj(2*Nj+indOrder,1), Xj(indOrder,1), Xj(Nj+indOrder,1), 'lineWidth', 2, 'color', [0,0,0]);

set(gcf, 'Position',  [100, 100, 1000, 600])
hold on

if show_control
    vec = [[cop(3,1), cop(3,1)+f_scale*fc(3,1)]; [cop(1,1), cop(1,1)+f_scale*fc(1,1)]; [cop(2,1), cop(2,1)+f_scale*fc(2,1)]; ...
          [cop(6,1), cop(6,1)+f_scale*fc(6,1)]; [cop(4,1), cop(4,1)+f_scale*fc(4,1)]; [cop(5,1), cop(5,1)+f_scale*fc(5,1)]];
    h_force_l = arrow3d(vec(1,:), vec(2,:), vec(3,:), 0.8, 0.005, 0.0025, [0.2,0.8,0.2]);
    h_force_r = arrow3d(vec(4,:), vec(5,:), vec(6,:), 0.8, 0.005, 0.0025, [0.2,0.8,0.2]);
    
    vec = [[cop(3,1), cop(3,1)+m_scale*fc(9,1)]; [cop(1,1), cop(1,1)+m_scale*fc(7,1)]; [cop(2,1), cop(2,1)+m_scale*fc(8,1)]; ...
          [cop(6,1), cop(6,1)+m_scale*fc(12,1)]; [cop(4,1), cop(4,1)+m_scale*fc(10,1)]; [cop(5,1), cop(5,1)+m_scale*fc(11,1)]];
    h_moment_l = arrow3d(vec(1,:), vec(2,:), vec(3,:), 0.8, 0.005, 0.0025, [0.2,0.2,0.9]);
    h_moment_r = arrow3d(vec(4,:), vec(5,:), vec(6,:), 0.8, 0.005, 0.0025, [0.2,0.2,0.9]);
    
    [x,y,z] = sphere;
    h_tau = cell(1,ntau);
    for i=1:ntau
        rad = tau(ind_tau(i),1)*tau_scale;
        h_tau{i} = surf(x*rad+tau_ctr(2*ntau+i,1), y*rad+tau_ctr(i,1), z*rad+tau_ctr(ntau+i,1), 'FaceColor',[0.8,0.2,0.2], ...
            'EdgeColor', 'none');

    end
end

ymax = max(max(Xj(1:Nj,:)));
ymin = min(min(Xj(1:Nj,:)));
zmax = max(max(Xj(Nj+1:2*Nj,:)));
zmin = min([min(min(Xj(Nj+1:2*Nj,:))),0]);
xmax = max(max(Xj(2*Nj+1:end,:)));
xmin = min(min(Xj(2*Nj+1:end,:)));

% plot ground
fill3([xmax xmin xmin xmax], [ymax ymax ymin ymin], zmin*ones(1,4),'k','FaceAlpha',0.3)

axis equal
axis([xmin-0.05, xmax+0.05, ymin-0.05, ymax+0.05, min(0,zmin-0.05), zmax+0.05]);
set(gca,'visible','off')
view([30,10]);

myVideo = VideoWriter(output);
myVideo.FrameRate = 10;
myVideo.Quality = 75;
open(myVideo)

% generate animation
for t = 1:length(tvec)
    set(h,'XData',Xj(2*Nj+indOrder,t),'YData',Xj(indOrder,t),'ZData',Xj(Nj+indOrder,t));
    if show_control
        vec = [[cop(3,t), cop(3,t)+f_scale*fc(3,t)]; [cop(1,t), cop(1,t)+f_scale*fc(1,t)]; [cop(2,t), cop(2,t)+f_scale*fc(2,t)]; ...
              [cop(6,t), cop(6,t)+f_scale*fc(6,t)]; [cop(4,t), cop(4,t)+f_scale*fc(4,t)]; [cop(5,t), cop(5,t)+f_scale*fc(5,t)]];
        [X1, Y1, Z1] = get_arrow3d_surfData(vec(1,:), vec(2,:), vec(3,:), 0.8, 0.005);
        [X2, Y2, Z2] = get_arrow3d_surfData(vec(4,:), vec(5,:), vec(6,:), 0.8, 0.005);
        set(h_force_l,'XData',X1,'YData',Y1,'ZData',Z1);
        set(h_force_r,'XData',X2,'YData',Y2,'ZData',Z2);
        
        vec = [[cop(3,t), cop(3,t)+m_scale*fc(9,t)]; [cop(1,t), cop(1,t)+m_scale*fc(7,t)]; [cop(2,t), cop(2,t)+m_scale*fc(8,t)]; ...
          [cop(6,t), cop(6,t)+m_scale*fc(12,t)]; [cop(4,t), cop(4,t)+m_scale*fc(10,t)]; [cop(5,t), cop(5,t)+m_scale*fc(11,t)]];
        [X1, Y1, Z1] = get_arrow3d_surfData(vec(1,:), vec(2,:), vec(3,:), 0.8, 0.005);
        [X2, Y2, Z2] = get_arrow3d_surfData(vec(4,:), vec(5,:), vec(6,:), 0.8, 0.005);
        set(h_moment_l,'XData',X1,'YData',Y1,'ZData',Z1);
        set(h_moment_r,'XData',X2,'YData',Y2,'ZData',Z2);
        
        for i=1:ntau
            rad = tau(ind_tau(i),t)*tau_scale;
            set(h_tau{i},'XData',x*rad+tau_ctr(2*ntau+i,t),'YData',y*rad+tau_ctr(i,t),'ZData',z*rad+tau_ctr(ntau+i,t));
        end
    end
    
    pause(0.01) % pause and grab frame
    frame = getframe(fig);
    writeVideo(myVideo, frame);

end
close(myVideo);
hold off

end

