function kin = generateModel_blade_legs(sub)
kin.N_S = 8; % number of segments
kin.N_J = 10; % number of joints
kin.DOF = 24; % degrees of freedom
kin.maxChainLen = 14;

kin.segInd = [1, 1, 2, 2, 2, 3, 3, 3];
kin.ns = [6, 8, 9, 12, 14, 9, 12, 14]; % number of links in chain i(s) until (com_s = end effector)
kin.jInd = [1, 1, 2, 2, 2, 2, 3, 3, 3, 3];
kin.nj = [3, 8, 6, 9, 12, 14, 6, 9, 12, 14];

kin.indShift = zeros(3,14);
kin.indShift(1,1:8) = 1:8;
kin.indShift(2,:) = [1:6,9:16];
kin.indShift(3,:) = [1:6,17:24];

l = sub.L;
c = sub.c;

% sub.L = [Lp, Lto, Lt, Ls, Lf]
% sub.c = [cto, ct, cs, cf]

% generalized coordinates
q = zeros(kin.DOF,1);

% all links
kin.L = [0,pi/2,q(1),pi/2; ...% 1
        0,pi/2,q(2),pi/2; ...% 2
        0,0,q(3),0; ...% 3
        0,pi/2,0,pi/2+q(4); ...% 4
        0,pi/2,0,pi/2+q(5); ...% 5
        0,0,0,q(6); ...% 6
        0,-pi/2,0,q(7); ...% 7
        c(1),0,0,q(8); ...% 8
        
        0,0,l(1)/2,q(6); ...% 9
        0,pi/2,0,pi/2+q(9); ...% 10
        0,pi/2,0,pi/2+q(10); ...% 11
        -l(3),pi/2,0,pi/2+q(11); ...% 12
        
        0,pi/2,0,pi/2+q(12); ...% 13
        0,pi/2,0,pi/2+q(13); ...% 14
        -l(4),pi/2,0,pi/2+q(14); ...% 15
        
        0,pi/2,0,pi/2+q(15); ...% 16
        l(5),0,0,q(16); ...% 17
        
        0,0,-l(1)/2,q(6); ...% 18
        0,pi/2,0,pi/2+q(17); ...% 19
        0,pi/2,0,pi/2+q(18); ...% 20
        -l(3),pi/2,0,pi/2+q(19); ...% 21
        
        0,pi/2,0,pi/2+q(20); ...% 22
        0,pi/2,0,pi/2+q(21); ...% 23
        -l(4),pi/2,0,pi/2+q(22); ...% 24
        
        0,pi/2,0,pi/2+q(23); ...% 25
        l(5),0,0,q(24)];% 26

% end-effector links
kin.segLink = [0,0,0,q(6); ...
              c(1),0,0,q(8); ...
              -c(2),pi/2,0,pi/2+q(11); ...
              -c(3),pi/2,0,pi/2+q(14); ...
              c(4),0,0,q(16); ...
              -c(2),pi/2,0,pi/2+q(19); ...
              -c(3),pi/2,0,pi/2+q(22); ...
              c(4),0,0,q(24)];

% kinematic subchains
kin.Chain = zeros(14,4,3);
kin.Chain(1:8,:,1) = kin.L(1:8,:);
kin.Chain(:,:,2) = kin.L([1:5,9:17],:);
kin.Chain(:,:,3) = kin.L([1:5,18:26],:);         

% initialization of matrices for kinematics and dynamics
kin.T = zeros(4,4*kin.maxChainLen,3);
kin.Z = zeros(3,kin.maxChainLen+1,3);
kin.P = zeros(3,kin.maxChainLen+1,3);
kin.Ts = zeros(4,4,kin.N_S);
kin.J = zeros(6*kin.N_S,kin.DOF);
kin.Rot = zeros(3*kin.N_S);
kin.G = zeros(6*kin.N_S,1);
kin.Jj = zeros(3*kin.N_J,kin.DOF);
kin.Xj = zeros(6*kin.N_J,1);
kin.Xs = zeros(9*kin.N_S,1);

end