% plotting force plate data (csv) and kinematics (bvh)
% frame rate: fr = 100 fps (except for subject 21: 200 fps)
% force plate frame rate = 10 * fr

root_path = pwd;

subject_id = 1;
filename = ['proband',int2str(subject_id),'_walk_1'];

folderpath = [root_path, '/', sprintf('%02i', subject_id), '/'];

%% force plate data
forcePlate = csvread([folderpath,filename,'.csv'], 5, 0);

force = forcePlate(:,[3:5, 12:14]);
moment = forcePlate(:,[6:8, 15:17]);
cop = forcePlate(:,[9:11, 18:20]);

figure(1); clf;
plot(force);
title('ground reaction force');

figure(2); clf;
plot(moment);
title('plate moment');

figure(3); clf;
plot(cop);
title('center of pressure');

%% kinematics
[skeleton,~] = loadbvh([folderpath,filename,'.bvh']);
% original code: https://github.com/wspr/bvh-matlab

h = figure(4); clf; hold on
set(h,'color','white')
view(-30,30)
axis equal off
Njoints = numel(skeleton);

ff = 1;

for nn = 1:Njoints

    plot3(skeleton(nn).Dxyz(1,ff),skeleton(nn).Dxyz(2,ff),skeleton(nn).Dxyz(3,ff),'.','markersize',20);

    parent = skeleton(nn).parent;
    if parent > 0
        plot3([skeleton(parent).Dxyz(1,ff) skeleton(nn).Dxyz(1,ff)],...
                     [skeleton(parent).Dxyz(2,ff) skeleton(nn).Dxyz(2,ff)],...
                     [skeleton(parent).Dxyz(3,ff) skeleton(nn).Dxyz(3,ff)]);
    end
end
